@@ -69,6 +69,8 @@ typedef enum
 static gint
 apv_get_format_int (GstMediaInfoTrack *track, const char *property_name)
 {
+#if 0
+FIXME for tag
 	GstProps *props;
 	GList *p;
 	if (track->format == NULL) return -1;
@@ -81,18 +83,17 @@ apv_get_format_int (GstMediaInfoTrack *track, const char *property_name)
 		GstPropsEntry *entry = (GstPropsEntry *) p->data;
 		const gchar *name;
 		gint int_val;
-		GstPropsType type;
 
 		name = gst_props_entry_get_name (entry);
-		type = gst_props_entry_get_type (entry);
-		if ((strcmp (name, property_name) == 0) &&
-		    type == GST_PROPS_INT_TYPE)
+		if ((strcmp (name, property_name) == 0))
 		{
 			gst_props_entry_get_int (entry, &int_val);
 			return int_val;
 		}
 		p = g_list_next (p);
       }
+#endif
+return 0;
 }
 
 static gchar *
@@ -100,6 +101,7 @@ apv_get_metadata_property (GstMediaInfoTrack *track,
 		           GstMediaInfoProperty property,
 			   const gchar *join_string)
 {
+#if 0
         gchar *result = NULL;
         GList *properties = NULL;
 
@@ -117,7 +119,6 @@ apv_get_metadata_property (GstMediaInfoTrack *track,
                 GstPropsEntry *entry = (GstPropsEntry *) p->data;
                 const gchar *name;
                 const gchar *val;
-                GstPropsType type;
 		gchar *property_name;
 
 		switch (property)
@@ -138,10 +139,8 @@ apv_get_metadata_property (GstMediaInfoTrack *track,
 
 
                 name = gst_props_entry_get_name (entry);
-                type = gst_props_entry_get_type (entry);
                 if (g_ascii_strncasecmp (name, property_name,
-					 strlen (property_name)) == 0 &&
-                    type == GST_PROPS_STRING_TYPE)
+					 strlen (property_name)) == 0)
 		{
 			/* get entry's value */
 			gchar *value;
@@ -167,6 +166,8 @@ apv_get_metadata_property (GstMediaInfoTrack *track,
 		p = g_list_next (p);
 	}
 	return result;
+#endif
+return g_strdup ("UNDER CONSTRUCTION");
 }
 
 /* public functions */
@@ -186,6 +187,8 @@ audio_properties_view_load_location (AudioPropertiesView *view,
 	GstMediaInfoTrack *track = NULL;
 	gchar *string = NULL;
 	gchar *c_string = NULL;
+	gchar *min_string = NULL;
+	gchar *sec_string = NULL;
 	gint channels;
 	gint min, sec, msec;
 
@@ -238,7 +241,8 @@ audio_properties_view_load_location (AudioPropertiesView *view,
 	if (channels == 1) c_string = g_strdup (_("mono"));
 	else if (channels == 2) c_string = g_strdup (_("stereo"));
 	else if (channels == 0) c_string = g_strdup (_("unknown"));
-	else c_string = g_strdup_printf (_("%d channels"), channels);
+ 	else c_string = g_strdup_printf (ngettext("%d channel","%d channels", channels), 
+ 					 channels);
 	string = g_strdup_printf ("%d Hz/%s/%d bit",
 			          apv_get_format_int (track, "rate"),
 				  c_string,
@@ -252,13 +256,22 @@ audio_properties_view_load_location (AudioPropertiesView *view,
 	min = sec / 60;
 	sec %= 60;
 
-	gtk_label_set_text (GTK_LABEL (view->length),
-			    g_strdup_printf (_("%d minutes %02d.%03d seconds"),
-				             min, sec, msec));
+	min_string = g_strdup_printf(ngettext("%d minute", "%d minutes", min), min);
+	/* Translators: plural form depends on the decimal part */
+	sec_string = g_strdup_printf(ngettext("%02d.%03d seconds", "%02d.%03d seconds", msec), sec, msec);
+	/* Translators: this is composed of '%d minute' and '%02d.%03d seconds'; change order if needed */
+	c_string = g_strdup_printf (_("%1$s %2$s"), min_string, sec_string);
+
+	g_free(min_string);
+	g_free(sec_string);
+
+	gtk_label_set_text (GTK_LABEL (view->length), c_string);
 	/* FIXME: start heated argument about k = 10^3 or 2^10 */
 	gtk_label_set_text (GTK_LABEL (view->bitrate),
 			    g_strdup_printf ("%.3f kbps",
 				             (double) stream->bitrate / 1024));
+
+	g_free (c_string);
 }
 
 GtkWidget *
