@@ -236,6 +236,7 @@ audio_view_props_to_string (GList *list, const gchar *prepend)
 	gchar *temp;
 	gchar *result = NULL;
 
+#if 0
 	p = list;
 	while (p)
 	{
@@ -259,6 +260,7 @@ audio_view_props_to_string (GList *list, const gchar *prepend)
 		p = g_list_next (p);
 	}
 	return result;
+#endif
 }
 /* returns a newly allocated human-readable type for the given mime type */
 static gchar *
@@ -315,14 +317,18 @@ audio_view_media_get_metadata (GstMediaInfoStream *info)
 	track = info->tracks->data;
 	if (track == NULL) return NULL;
 	if (track->metadata == NULL) return NULL;
+#if 0
 	if (track->metadata->properties == NULL) return NULL;
 
 	p = track->metadata->properties->properties;
+#endif
 
         if (!p) /* no metadata */
                 return g_strdup (_("Unknown"));
 
 	/* construct GLists of GstPropsEntries to artist and title */
+#if 0
+FIXME: GstPropsEntry is gone, get the right way of tagging extraction done here
 	while (p)
 	{
 		GstPropsEntry *entry = (GstPropsEntry *) p->data;
@@ -353,6 +359,7 @@ audio_view_media_get_metadata (GstMediaInfoStream *info)
 
 	/* we chomp because it looks better in the list view */
 	return g_strchomp (metadata);
+#endif
 }
 
 /* set next track to play
