@@ -106,16 +106,9 @@ deep_notify_callback (GObject *object, GstObject *origin,
       g_object_get_property (G_OBJECT (origin), pspec->name, &value);
       priv->format = g_value_peek_pointer (&value);
     }
-    else
-    {
-      /* FIXME: somehow with 0.7.2 the signalisation comes from typefind:src */
-      GMI_DEBUG("DEBUG: taking caps from object %s:%s\n",
+    else GMI_DEBUG("DEBUG: igoring caps on object %s:%s\n",
 		   gst_object_get_name (gst_object_get_parent (origin)),
 		   gst_object_get_name (origin));
-      g_value_init (&value, pspec->value_type);
-      g_object_get_property (G_OBJECT (origin), pspec->name, &value);
-      priv->format = g_value_peek_pointer (&value);
-    }
   }
   else if (strcmp (pspec->name, "offset") == 0)
   {
@@ -143,13 +136,13 @@ gmi_reset (GstMediaInfo *info)
   if (priv->format)
   {
     GMI_DEBUG ("unreffing priv->format, error before this ?\n");
-    gst_caps_unref (priv->format);
+    gst_caps_free (priv->format);
     priv->format = NULL;
   }
   if (priv->metadata)
   {
     GMI_DEBUG ("unreffing priv->metadata, error before this ?\n");
-    gst_caps_unref (priv->metadata);
+    gst_caps_free (priv->metadata);
     priv->metadata = NULL;
   }
   if (priv->stream)
@@ -200,12 +193,12 @@ gmi_seek_to_track (GstMediaInfo *info, long track)
   /* clear structs because of the seek */
   if (priv->metadata)
   {
-    gst_caps_unref (priv->metadata);
+    gst_caps_free (priv->metadata);
     priv->metadata = NULL;
   }
   if (priv->streaminfo)
   {
-    gst_caps_unref (priv->streaminfo);
+    gst_caps_free (priv->streaminfo);
     priv->streaminfo = NULL;
   }
   return TRUE;
@@ -311,7 +304,7 @@ gmip_find_type_pre (GstMediaInfoPriv *priv)
   if (priv->type)
   {
     /* we don't need to unref, this is done inside gsttypefind.c
-       gst_caps_unref (priv->type);
+       gst_caps_free (priv->type);
      */
     priv->type = NULL;
   }
@@ -580,14 +573,13 @@ gmip_find_track_streaminfo_post (GstMediaInfoPriv *priv)
                               &format, &value_end);
       if (res)
       {
-	GstPropsEntry *length;
         /* substract to get the length */
 	GMI_DEBUG("DEBUG: start %lld, end %lld\n", value_start, value_end);
 	value_end -= value_start;
 	/* FIXME: check units; this is in seconds */
-	length = gst_props_entry_new ("length",
-			              GST_PROPS_INT ((int) (value_end / 1E6)));
-	gst_props_add_entry (gst_caps_get_props (priv->streaminfo), length);
+
+	gst_caps_set_simple (priv->streaminfo,
+	    "length", G_TYPE_INT, (int) (value_end / 1E6), NULL);
       }
     }
   }
